Documentation
¶
Index ¶
Constants ¶
const ( StatusConditionRestarting = "Restarting" StatusConditionRunning = "Running" )
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CFAppReconciler ¶
type CFAppReconciler struct {
Client CFClient
Scheme *runtime.Scheme
Log logr.Logger
ControllerConfig *config.ControllerConfig
}
CFAppReconciler reconciles a CFApp object
func (*CFAppReconciler) Reconcile ¶
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. TODO(user): Modify the Reconcile function to compare the state specified by the CFApp object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.8.3/pkg/reconcile
func (*CFAppReconciler) SetupWithManager ¶
func (r *CFAppReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type CFBuildReconciler ¶
type CFBuildReconciler struct {
Client CFClient
Scheme *runtime.Scheme
Log logr.Logger
ControllerConfig *config.ControllerConfig
RegistryAuthFetcher RegistryAuthFetcher
ImageProcessFetcher ImageProcessFetcher
}
CFBuildReconciler reconciles a CFBuild object
func (*CFBuildReconciler) Reconcile ¶
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. TODO(user): Modify the Reconcile function to compare the state specified by the CFBuild object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.8.3/pkg/reconcile
func (*CFBuildReconciler) SetupWithManager ¶
func (r *CFBuildReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type CFClient ¶
type CFClient interface {
Get(ctx context.Context, key client.ObjectKey, obj client.Object) error
Create(ctx context.Context, obj client.Object, opts ...client.CreateOption) error
List(ctx context.Context, list client.ObjectList, opts ...client.ListOption) error
Patch(ctx context.Context, obj client.Object, patch client.Patch, opts ...client.PatchOption) error
Update(ctx context.Context, obj client.Object, opts ...client.UpdateOption) error
Status() client.StatusWriter
}
type CFPackageReconciler ¶
CFPackageReconciler reconciles a CFPackage object
func (*CFPackageReconciler) Reconcile ¶
Reconcile is part of the main kubernetes reconciliation loop which aims to move the current state of the cluster closer to the desired state. TODO(user): Modify the Reconcile function to compare the state specified by the CFPackage object against the actual cluster state, and then perform operations to make the cluster state reflect the state specified by the user.
For more details, check Reconcile and its Result here: - https://pkg.go.dev/sigs.k8s.io/controller-runtime@v0.8.3/pkg/reconcile
func (*CFPackageReconciler) SetupWithManager ¶
func (r *CFPackageReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type CFProcessReconciler ¶
CFProcessReconciler reconciles a CFProcess object
func (*CFProcessReconciler) SetupWithManager ¶
func (r *CFProcessReconciler) SetupWithManager(mgr ctrl.Manager) error
SetupWithManager sets up the controller with the Manager.
type ImageProcessFetcher ¶
type ImageProcessFetcher func(imageRef string, credsOption remote.Option) ([]workloadsv1alpha1.ProcessType, []int32, error)
type RegistryAuthFetcher ¶
func NewRegistryAuthFetcher ¶
func NewRegistryAuthFetcher(privilegedK8sClient k8sclient.Interface) RegistryAuthFetcher